***************
Getting started
***************

This is a beginner friendly tutorial on how to use Antidote.
It is a series of steps to show what can be done easily. Note that Antidote can do a lot
more than presented here, don't hesitate to check out the recipes and references for
more in depth documentation.

.. toctree::
    :maxdepth: 2

    tutorial/1_introduction
    tutorial/2_injection
    tutorial/3_injectable
    tutorial/4_constant
    tutorial/5_lazy
    tutorial/6_tests
